
<img src="https://user-images.githubusercontent.com/2452935/181300325-502f1791-51cf-4618-b00f-b90609d6e862.png" width="100">

ThermoPot: An ab-initio thermodynamic modelling package [![DOI](https://zenodo.org/badge/490745937.svg)](https://zenodo.org/badge/latestdoi/490745937)
============================

⚠️ This repository is still in development, and some functionality is untested. Use with caution.

![example workflow](https://github.com/NU-CEM/ThermoPot/actions/workflows/build-docs.yml/badge.svg) ![example workflow](https://github.com/NU-CEM/ThermoPot/actions/workflows/run-tests.yml/badge.svg) ![example workflow](https://github.com/NU-CEM/ThermoPot/actions/workflows/lint-code.yml/badge.svg)

Software for ab-initio thermodynamic modelling of material formation and decomposition.

- 📚 The documentation is [here](https://NU-CEM.github.io/ThermoPot).
- 🖊 If you use this package for your own work please [cite accordingly](https://github.com/NU-CEM/ThermoPot/blob/main/citation.cff).
- 🔄 This code is made available under the GNU General Public Licence (GPL) v3. 

This work adapts and extends a previous repository developed by Adam Jackson: [Thermodynamic model of CZTS](http://dx.doi.org/10.5281/zenodo.57130). 






